@@ -6,17 +6,13 @@ import json
 import subprocess
 from pathlib import Path
 
-import click
 import requests
 import typer
 import yaml
-from rich.console import Console
 
 from hud.settings import settings
 from hud.utils.design import HUDDesign
 
-console = Console()
-
 
 def get_docker_username() -> str | None:
     """Get the current Docker username if logged in."""
@@ -51,9 +47,9 @@ def get_docker_username() -> str | None:
                                 if username and username != "token":  # Skip token-based auth
                                     return username
                             except Exception:
-                                click.echo("Failed to decode auth info", err=True)
+                                pass  # Silent failure, try other methods
                 except Exception:
-                    click.echo("Failed to get Docker username", err=True)
+                    pass  # Silent failure, try other methods
 
         # Alternative: Check credsStore/credHelpers
         for config_path in config_paths:
@@ -89,11 +85,11 @@ def get_docker_username() -> str | None:
                                             if username and username != "token":
                                                 return username
                         except Exception:
-                            click.echo("Failed to get Docker username", err=True)
+                            pass  # Silent failure, try other methods
                 except Exception:
-                    click.echo("Failed to get Docker username", err=True)
+                    pass  # Silent failure, try other methods
     except Exception:
-        click.echo("Failed to get Docker username", err=True)
+        pass  # Silent failure, try other methods
     return None
 
 
@@ -108,7 +104,6 @@ def get_docker_image_labels(image: str) -> dict:
         )
         return json.loads(result.stdout.strip()) or {}
     except Exception:
-        click.echo("Failed to get Docker image labels", err=True)
         return {}
 
 
@@ -136,11 +131,12 @@ def push_environment(
     # Check for API key first
     if not settings.api_key:
         design.error("No HUD API key found")
-        console.print("\n[yellow]A HUD API key is required to push environments.[/yellow]")
-        console.print("\nTo get started:")
-        console.print("  1. Get your API key at: [link]https://hud.so/settings[/link]")
-        console.print("  2. Set it: [cyan]export HUD_API_KEY=your-key-here[/cyan]")
-        console.print("  3. Try again: [cyan]hud push[/cyan]\n")
+        design.warning("A HUD API key is required to push environments.")
+        design.info("\nTo get started:")
+        design.info("1. Get your API key at: https://hud.so/settings")
+        design.command_example("export HUD_API_KEY=your-key-here", "Set your API key")
+        design.command_example("hud push", "Try again")
+        design.info("")
         raise typer.Exit(1)
 
     # Load lock file
@@ -152,6 +148,9 @@ def push_environment(
     if not local_image and "build" in lock_data:
         # New format might have image elsewhere
         local_image = lock_data.get("image", "")
+    
+    # Get internal version from lock file
+    internal_version = lock_data.get("build", {}).get("version", None)
 
     # If no image specified, try to be smart
     if not image:
@@ -172,14 +171,20 @@ def push_environment(
             if "/" in base_name:
                 base_name = base_name.split("/")[-1]
 
-            # Use provided tag or default
-            final_tag = tag if tag else current_tag
+            # Use provided tag, or internal version, or current tag as fallback
+            if tag:
+                final_tag = tag
+                design.info(f"Using specified tag: {tag}")
+            elif internal_version:
+                final_tag = internal_version
+                design.info(f"Using internal version from lock file: {internal_version}")
+            else:
+                final_tag = current_tag
+                design.info(f"Using current tag: {current_tag}")
 
             # Suggest a registry image
             image = f"{username}/{base_name}:{final_tag}"
             design.info(f"Auto-detected Docker username: {username}")
-            if tag:
-                design.info(f"Using specified tag: {tag}")
             design.info(f"Will push to: {image}")
 
             if not yes and not typer.confirm(f"\nPush to {image}?"):
@@ -190,44 +195,77 @@ def push_environment(
                 "Not logged in to Docker Hub. Please specify --image or run 'docker login'"
             )
             raise typer.Exit(1)
-    elif tag:
+    elif tag or internal_version:
         # Handle tag when image is provided
+        # Prefer explicit tag over internal version
+        final_tag = tag if tag else internal_version
+        
         if ":" in image:
             # Image already has a tag
             existing_tag = image.split(":")[-1]
-            if existing_tag != tag:
-                design.warning(f"Image already has tag '{existing_tag}', overriding with '{tag}'")
-                image = image.rsplit(":", 1)[0] + f":{tag}"
+            if existing_tag != final_tag:
+                if tag:
+                    design.warning(f"Image already has tag '{existing_tag}', overriding with '{final_tag}'")
+                else:
+                    design.info(f"Image has tag '{existing_tag}', but using internal version '{final_tag}'")
+                image = image.rsplit(":", 1)[0] + f":{final_tag}"
             # else: tags match, no action needed
         else:
-            # Image has no tag, append the specified one
-            image = f"{image}:{tag}"
-        design.info(f"Using specified tag: {tag}")
+            # Image has no tag, append the appropriate one
+            image = f"{image}:{final_tag}"
+            
+        if tag:
+            design.info(f"Using specified tag: {tag}")
+        else:
+            design.info(f"Using internal version from lock file: {internal_version}")
         design.info(f"Will push to: {image}")
 
     # Verify local image exists
     # Extract the tag part (before @sha256:...) for Docker operations
     local_tag = local_image.split("@")[0] if "@" in local_image else local_image
+    
+    # Also check for version-tagged image if we have internal version
+    version_tag = None
+    if internal_version and ":" in local_tag:
+        base_name = local_tag.split(":")[0]
+        version_tag = f"{base_name}:{internal_version}"
 
-    # Verify the image exists locally
-    try:
-        subprocess.run(["docker", "inspect", local_tag], capture_output=True, check=True)  # noqa: S603, S607
-    except subprocess.CalledProcessError:
-        design.error(f"Local image not found: {local_tag}")
-        design.info("Run 'hud build' first to create the image")
-        raise typer.Exit(1)  # noqa: B904
+    # Try to find the image - prefer version tag if it exists
+    image_to_push = None
+    if version_tag:
+        try:
+            subprocess.run(["docker", "inspect", version_tag], capture_output=True, check=True)  # noqa: S603, S607
+            image_to_push = version_tag
+            design.info(f"Found version-tagged image: {version_tag}")
+        except subprocess.CalledProcessError:
+            pass
+    
+    if not image_to_push:
+        try:
+            subprocess.run(["docker", "inspect", local_tag], capture_output=True, check=True)  # noqa: S603, S607
+            image_to_push = local_tag
+        except subprocess.CalledProcessError:
+            design.error(f"Local image not found: {local_tag}")
+            if version_tag:
+                design.error(f"Also tried: {version_tag}")
+            design.info("Run 'hud build' first to create the image")
+            raise typer.Exit(1)  # noqa: B904
 
     # Check if local image has the expected label
-    labels = get_docker_image_labels(local_tag)
+    labels = get_docker_image_labels(image_to_push)
     expected_label = labels.get("org.hud.manifest.head", "")
+    version_label = labels.get("org.hud.version", "")
 
     # Skip hash verification - the lock file may have been updated with digest after build
-    if verbose and expected_label:
-        design.info(f"Image label: {expected_label[:12]}...")
+    if verbose:
+        if expected_label:
+            design.info(f"Image label: {expected_label[:12]}...")
+        if version_label:
+            design.info(f"Version label: {version_label}")
 
     # Tag the image for push
-    design.progress_message(f"Tagging {local_tag} as {image}")
-    subprocess.run(["docker", "tag", local_tag, image], check=True)  # noqa: S603, S607
+    design.progress_message(f"Tagging {image_to_push} as {image}")
+    subprocess.run(["docker", "tag", image_to_push, image], check=True)  # noqa: S603, S607
 
     # Push the image
     design.progress_message(f"Pushing {image} to registry...")
@@ -243,7 +281,7 @@ def push_environment(
     )
 
     for line in process.stdout or []:
-        click.echo(line.rstrip(), err=True)
+        design.info(line.rstrip())
 
     process.wait()
 
@@ -267,8 +305,8 @@ def push_environment(
     design.success("Push complete!")
 
     # Show the final image reference
-    console.print("\n[bold green]✓ Pushed image:[/bold green]")
-    console.print(f"  [bold cyan]{pushed_digest}[/bold cyan]\n")
+    design.section_title("Pushed Image")
+    design.status_item("Registry", pushed_digest, primary=True)
 
     # Update the lock file with registry information
     lock_data["image"] = pushed_digest
@@ -286,7 +324,7 @@ def push_environment(
     with open(lock_path, "w") as f:
         yaml.dump(lock_data, f, default_flow_style=False, sort_keys=False)
 
-    console.print("[green]✓[/green] Updated lock file with registry image")
+    design.success("Updated lock file with registry image")
 
     # Upload lock file to HUD registry
     try:
@@ -324,43 +362,30 @@ def push_environment(
 
             if response.status_code in [200, 201]:
                 design.success("Metadata uploaded to HUD registry")
-                console.print(
-                    f"  Others can now pull with: [cyan]hud pull {name_with_tag}[/cyan]\n"
-                )
+                design.info("Others can now pull with:")
+                design.command_example(f"hud pull {name_with_tag}")
+                design.info("")
             else:
                 design.warning(f"Could not upload to registry: {response.status_code}")
                 if verbose:
                     design.info(f"Response: {response.text}")
-                console.print("  Share [cyan]hud.lock.yaml[/cyan] manually\n")
+                design.info("Share hud.lock.yaml manually\n")
         else:
             if verbose:
                 design.info("Could not parse registry path for upload")
-            console.print(
-                "  Share [cyan]hud.lock.yaml[/cyan] to let others reproduce your exact environment\n"  # noqa: E501
-            )
+            design.info("Share hud.lock.yaml to let others reproduce your exact environment\n")
     except Exception as e:
         design.warning(f"Registry upload failed: {e}")
-        console.print("  Share [cyan]hud.lock.yaml[/cyan] manually\n")
+        design.info("Share hud.lock.yaml manually\n")
 
     # Show usage examples
     design.section_title("What's Next?")
 
-    console.print("Test locally:")
-    console.print(f"  [cyan]hud run {image}[/cyan]\n")
-
-    console.print("Use in MCP configs:")
-    console.print("  Claude Desktop:")
-    console.print(
-        f'    [cyan]{{"docker": {{"image": "{pushed_digest}", "command": "auto"}}}}[/cyan]\n'
-    )
-
-    console.print("  Via HUD (recommended):")
-    console.print(f'    [cyan]{{"hud": {{"registry": "{pushed_digest}"}}}}[/cyan]\n')
-
-    console.print("Share environment:")
-    console.print(
-        "  Share the updated [cyan]hud.lock.yaml[/cyan] for others to reproduce your exact environment"  # noqa: E501
-    )
+    design.info("Test locally:")
+    design.command_example(f"hud run {image}")
+    design.info("")
+    design.info("Share environment:")
+    design.info("  Share the updated hud.lock.yaml for others to reproduce your exact environment")
 
     # TODO: Upload lock file to HUD registry
     if sign:
